@@ -27,10 +27,13 @@ class PluginsModel : public QStandardItemModel
 	Q_OBJECT
 	public:
 		enum Roles { PathRole = Qt::UserRole+1, PriorityRole, TitleRole, SubtitleRole };
-		
+
 		explicit PluginsModel(QObject* parent = 0);
+		virtual QHash<int, QByteArray> roleNames() const;
 		
-	public slots:
+		static QString pluginsDirectoryPath();
+
+	public Q_SLOTS:
 		///qml can't access data. Yay!
 		QString pluginPath(int row);
 };
