@@ -27,15 +27,14 @@
 #include <QTextDocument>
 #include <qevent.h>
 #include <QDir>
+#include <qurlquery.h>
 #include <QWebFrame>
 
-#include <KLocale>
 #include <KStandardAction>
-#include <KMenu>
-#include <KHTMLView>
-#include <KAction>
+#include <QMenu>
+#include <KLocalizedString>
+#include <QAction>
 #include <kio/copyjob.h>
-#include <kio/netaccess.h>
 #include <kio/job.h>
 
 #include <analitza/variables.h>
@@ -84,8 +83,9 @@ void ConsoleHtml::initialize()
 
 void ConsoleHtml::openClickedUrl(const QUrl& url)
 {
-	QString id =url.queryItemValue("id");
-	QString exp=url.queryItemValue("func");
+	QUrlQuery query(url);
+	QString id =query.queryItemValue("id");
+	QString exp=query.queryItemValue("func");
 	
 	foreach(InlineOptions* opt, m_options) {
 		if(opt->id() == id) {
@@ -121,11 +121,12 @@ bool ConsoleHtml::addOperation(const Analitza::Expression& e, const QString& inp
 		
 		foreach(InlineOptions* opt, m_options) {
 			if(opt->matchesExpression(lambdaexp, functype)) {
-				KUrl url("/query");
-				url.addQueryItem("id", opt->id());
-				url.addQueryItem("func", lambdaexp.toString());
+				QUrl url("/query");
+				QUrlQuery query(url);
+				query.addQueryItem("id", opt->id());
+				query.addQueryItem("func", lambdaexp.toString());
 				
-				options += i18n(" <a href='%1'>%2</a>", url.url(), opt->caption());
+				options += i18n(" <a href='%1'>%2</a>", query.toString(), opt->caption());
 			}
 		}
 		
@@ -136,7 +137,7 @@ bool ConsoleHtml::addOperation(const Analitza::Expression& e, const QString& inp
 		m_script += e; //Script won't have the errors
 		newEntry = QString("%1<br />=<span class='result'>%2</span>").arg(e.toHtml()).arg(result);
 	} else {
-		m_htmlLog += i18n("<ul class='error'>Error: <b>%1</b><li>%2</li></ul>", Qt::escape(input), a.errors().join("</li>\n<li>"));
+		m_htmlLog += i18n("<ul class='error'>Error: <b>%1</b><li>%2</li></ul>", input.toHtmlEscaped(), a.errors().join("</li>\n<li>"));
 	}
 	
 	updateView(newEntry, options);
@@ -153,20 +154,20 @@ QString temporaryPath()
 	return QDir::tempPath()+'/'+temp.fileName();
 }
 
-QString ConsoleHtml::retrieve(const KUrl& remoteUrl)
+QString ConsoleHtml::retrieve(const QUrl& remoteUrl)
 {
 	QString path=temporaryPath();
 	
-	KIO::CopyJob* job=KIO::copyAs(remoteUrl, KUrl(path));
+	KIO::CopyJob* job=KIO::copyAs(remoteUrl, QUrl(path));
 	
-	bool ret = KIO::NetAccess::synchronousRun(job, 0);
+	bool ret = job->exec();
 	if(!ret)
 		path.clear();
 	
 	return path;
 }
 
-bool ConsoleHtml::loadScript(const KUrl& path)
+bool ConsoleHtml::loadScript(const QUrl& path)
 {
 	Q_ASSERT(!path.isEmpty());
 	
@@ -182,16 +183,16 @@ bool ConsoleHtml::loadScript(const KUrl& path)
 	}
 	
 	if(!correct) {
-		m_htmlLog += i18n("<ul class='error'>Error: Could not load %1. <br /> %2</ul>", path.pathOrUrl(), a.errors().join("<br/>"));
+		m_htmlLog += i18n("<ul class='error'>Error: Could not load %1. <br /> %2</ul>", path.toString(), a.errors().join("<br/>"));
 		updateView(QString(), QString());
 	}
 	else
-		updateView(i18n("Imported: %1", path.pathOrUrl()), QString());
+		updateView(i18n("Imported: %1", path.toString()), QString());
 	
 	return correct;
 }
 
-bool ConsoleHtml::saveScript(const KUrl & path) const
+bool ConsoleHtml::saveScript(const QUrl & path) const
 {
 	bool correct=false;
 	Q_ASSERT(!path.isEmpty());
@@ -207,13 +208,13 @@ bool ConsoleHtml::saveScript(const KUrl & path) const
 	}
 	
 	if(!path.isLocalFile()) {
-		KIO::CopyJob* job=KIO::move(savePath, path);
-		correct=KIO::NetAccess::synchronousRun(job, 0);
+		KIO::CopyJob* job=KIO::move(QUrl(savePath), path);
+		correct=job->exec();
 	}
 	return correct;
 }
 
-bool ConsoleHtml::saveLog(const KUrl& path) const
+bool ConsoleHtml::saveLog(const QUrl& path) const
 {
 	Q_ASSERT(!path.isEmpty());
 	//FIXME: We have to choose between txt and html
@@ -232,8 +233,8 @@ bool ConsoleHtml::saveLog(const KUrl& path) const
 	}
 	
 	if(!path.isLocalFile()) {
-		KIO::CopyJob* job=KIO::move(savePath, path);
-		correct=KIO::NetAccess::synchronousRun(job, 0);
+		KIO::CopyJob* job=KIO::move(QUrl(savePath), path);
+		correct=job->exec();
 	}
 	return correct;
 }
@@ -270,10 +271,10 @@ void ConsoleHtml::copy() const
 
 void ConsoleHtml::contextMenuEvent(QContextMenuEvent* ev)
 {
-	KMenu popup;
+	QMenu popup;
 	if(hasSelection()) {
 		popup.addAction(KStandardAction::copy(this, SLOT(copy()), &popup));
-		KAction *act=new KAction(KIcon("edit-paste"), i18n("Paste \"%1\" to input", selectedText()), &popup);
+		QAction *act=new QAction(QIcon::fromTheme("edit-paste"), i18n("Paste \"%1\" to input", selectedText()), &popup);
 		connect(act, SIGNAL(triggered()), SLOT(paste()));
 		popup.addAction(act);
 		popup.addSeparator();
